@@ -18,7 +18,7 @@ namespace code {
 			 * Transform.
 			 */
 
-			virtual Listing *STORM_FN transform(Listing *src) const;
+			virtual code::Arena::TransformInfo STORM_FN transformInfo(Listing *src) const;
 			virtual void STORM_FN output(Listing *src, Output *to) const;
 
 			/**
@@ -33,6 +33,7 @@ namespace code {
 			 */
 
 			virtual void STORM_FN removeFnRegs(RegSet *from) const;
+			virtual RegSet *STORM_FN fnResultRegs() const;
 
 			/**
 			 * Misc.
@@ -44,6 +45,13 @@ namespace code {
 			virtual Operand STORM_FN firstParamLoc(Nat id);
 			virtual Reg STORM_FN functionDispatchReg();
 
+			/**
+			 * Replacing functions.
+			 */
+
+			virtual code::Arena::Skeleton *STORM_FN compatibleFrameSkeleton(Binary *binary, Nat offset);
+			virtual void STORM_FN resizeStackFrame(Listing *out, Reg tmpReg, Binary *newSz);
+
 		};
 
 	}
