@@ -180,6 +180,8 @@ namespace code {
 		for (Nat i = state.src->count(); i > 0; i--) {
 			Nat line = i - 1;
 			Instr *instr = state.src->at(line);
+			if (instr->op() == op::shadowMov)
+				continue;
 
 			if (isLabelJump(instr)) {
 				Nat target = instr->dest().label().key();
@@ -226,6 +228,8 @@ namespace code {
 		for (Nat i = start + 1; i > 0; i--) {
 			Nat line = i - 1;
 			Instr *instr = state.src->at(line);
+			if (instr->op() == op::shadowMov)
+				continue;
 
 			if (isLabelJump(instr)) {
 				processJump(state, instr, instr->dest().label().key(), usedNow);
@@ -288,6 +292,9 @@ namespace code {
 		for (Nat i = 0; i < src->count(); i++) {
 			Instr *instr = src->at(i);
 
+			if (instr->op() == op::shadowMov)
+				continue;
+
 			if (instr->mode() & destWrite)
 				*all += instr->dest();
 		}
