@@ -119,6 +119,10 @@ namespace code {
 			}
 		}
 
+		void shadowMovOut(Output *to, Instr *instr) {
+			movOut(to, instr);
+		}
+
 		void swapOut(Output *to, Instr *instr) {
 			if (instr->size() == Size::sByte) {
 				to->putByte(0x86);
@@ -272,7 +276,7 @@ namespace code {
 
 		void testOut(Output *to, Instr *instr) {
 			ImmRegInstr8 op8 = {
-				0xF6, 7,
+				0xF6, 0,
 				0x84,
 				0x84 // TEST is symmetric
 			};
@@ -314,6 +318,10 @@ namespace code {
 				to->putByte(0x68);
 				to->putObject(src.object());
 				break;
+			case opOffReference:
+				to->putByte(0x68);
+				to->putPtr(src.offsetRef());
+				break;
 			case opLabel:
 				to->putByte(0x68);
 				to->putAddress(src.label());
@@ -373,8 +381,11 @@ namespace code {
 				to->putRelative(src.label());
 				break;
 			case opReference:
+				// Note: We could just use 'putRelative' here. However, for reloading, we need to
+				// find all call sites, so we use the special form "jump" instead. For x86, this
+				// works exactly like the regular 'relative' mode.
 				to->putByte(opCode);
-				to->putRelative(src.ref());
+				to->putGc(GcCodeRef::jump, 4, src.ref());
 				break;
 			default:
 				assert(false, L"JmpCall not implemented for " + ::toS(src));
@@ -384,8 +395,11 @@ namespace code {
 
 		static void jmpCall(bool call, Output *to, const Operand &src) {
 			switch (src.type()) {
-			case opConstant:
 			case opLabel:
+				if (!call)
+					to->markJump(src.label());
+				// Fall through
+			case opConstant:
 			case opReference:
 				jmpCall(byte(call ? 0xE8 : 0xE9), to, src);
 				break;
@@ -554,6 +568,11 @@ namespace code {
 					to->putInt(Nat(src.constant()));
 				}
 				break;
+			case opOffReference:
+				to->putByte(0x69);
+				modRm(to, registerId(reg), instr->dest());
+				to->putInt(src.offsetRef());
+				break;
 			case opLabel:
 			case opReference:
 			case opObjReference:
@@ -604,6 +623,10 @@ namespace code {
 				// Special meaning, load the RefSource instead.
 				to->putByte(0xB8 + regId);
 				to->putObject(src.refSource());
+			} else if (src.type() == opOffReference) {
+				// Special meaning, load the RefSource instead.
+				to->putByte(0xB8 + regId);
+				to->putObject(src.offsetRef().source());
 			} else {
 				to->putByte(0x8D);
 				modRm(to, regId, src);
@@ -950,11 +973,19 @@ namespace code {
 			case opObjReference:
 				to->putObject(src.object());
 				break;
+			case opOffReference:
+				if (src.size() == Size::sInt)
+					to->putInt(src.offsetRef());
+				else if (src.size() == Size::sPtr)
+					to->putPtr(src.offsetRef());
+				else
+					throw new (to) InternalError(S("Unable to output offsets as anything but pointers or ints."));
+				break;
 			case opConstant:
 				to->putSize(src.constant(), src.size());
 				break;
 			default:
-				assert(false, L"Unsupported type for dat.");
+				throw new (to) InternalError(S("Unsupported type for 'dat'."));
 				break;
 			}
 		}
@@ -983,6 +1014,7 @@ namespace code {
 			OUTPUT(nop),
 			OUTPUT(epilog),
 			OUTPUT(mov),
+			OUTPUT(shadowMov),
 			OUTPUT(swap),
 			OUTPUT(add),
 			OUTPUT(adc),
