@@ -14,6 +14,7 @@ namespace code {
 
 		const OpEntry<RemoveInvalid::TransformFn> RemoveInvalid::transformMap[] = {
 			IMM_REG(mov),
+			IMM_REG(shadowMov),
 			IMM_REG(add),
 			IMM_REG(adc),
 			IMM_REG(bor),
@@ -94,6 +95,7 @@ namespace code {
 			case opReference:
 			case opConstant:
 			case opObjReference:
+			case opOffReference:
 			case opRegister:
 				return true;
 			default:
@@ -502,9 +504,9 @@ namespace code {
 		static Operand offset(const Operand &src, Offset offset) {
 			switch (src.type()) {
 			case opVariable:
-				return xRel(Size::sInt, src.var(), offset);
-			case opRegister:
-				return xRel(Size::sInt, src.reg(), offset);
+				return xRel(Size::sInt, src.var(), src.offsetRef() + offset);
+			case opRelative:
+				return xRel(Size::sInt, src.reg(), src.offsetRef() + offset);
 			default:
 				assert(false, L"Can not generate offsets into this type!");
 				return Operand();
