@@ -48,7 +48,7 @@ namespace storm {
 			// Trick the function into believing that it has a proper name (just like
 			// lambdas). Necessary in order to be able to call 'runOn', which is done when we create
 			// function pointers to the function.
-			r->parentLookup = scope.top;
+			r->parentLookup(scope.top);
 			r->runOn(thread);
 			return r;
 		}
