@@ -11,13 +11,16 @@ namespace storm {
 		// No flags, default behaviour.
 		namedDefault = 0x00,
 
-		/**
-		 * Flags for function matching.
-		 */
-
 		// Ignore inheritance when matching types for this Named.
 		namedMatchNoInheritance = 0x01,
 
+		// Be strict with matching references vs no references.
+		namedStrictRef = 0x02,
+
+		// This entity was implicitly generated at some point. Allow replacing it whenever a new
+		// exact match is inserted.
+		namedAllowReplace = 0x04,
+
 	};
 
 	BITMASK_OPERATORS(NamedFlags);
