@@ -66,6 +66,7 @@ namespace storm {
 		// 'createDesc' and the supplied size rather than the members defined here. Only usable for
 		// value types.
 		STORM_CTOR Type(Str *name, Array<Value> *params, TypeFlags flags, Size size);
+		STORM_CTOR Type(SrcPos pos, Str *name, Array<Value> *params, TypeFlags flags, Size size);
 
 	public:
 		// Create a type declared in C++.
@@ -116,6 +117,10 @@ namespace storm {
 		using NameSet::add;
 		virtual void STORM_FN add(Named *item);
 
+		// ...and removed.
+		using NameSet::remove;
+		virtual Bool STORM_FN remove(Named *item);
+
 		// Modify the 'find' behaviour slightly so it also considers superclasses.
 		virtual MAYBE(Named *) STORM_FN find(SimplePart *part, Scope source);
 		using NameSet::find;
@@ -186,6 +191,10 @@ namespace storm {
 		// Add a flag to the set of type flags.
 		void STORM_FN addTypeFlag(TypeFlags flags);
 
+		// Convenience to check if this type is a value type.
+		Bool STORM_FN isValue() const { return (typeFlags() & typeValue) == typeValue; }
+		Bool STORM_FN isClass() const { return (typeFlags() & typeClass) == typeClass; }
+
 		// Get a compact description of this type, used to know how this type shall be passed to
 		// functions in the system.
 		code::TypeDesc *STORM_FN typeDesc();
@@ -217,7 +226,30 @@ namespace storm {
 		typedef void (*CopyCtorFn)(void *, const void *);
 		CopyCtorFn CODECALL rawCopyConstructor();
 
+		// Check if the vtable from an object, passed as 'vtable', matches the one in this type.
+		// Intended to be used from 'typeOf' to detect cases where the 'object' is not yet fully
+		// constructed, and return a parent-type in those cases. Therefore, this function needs to
+		// be thread-safe enough to work in these cases. Since the operation is very common (used on
+		// all downcasts), it is not feasible to synchronize or perform thread switches here.
+		inline Bool hasVTable(const void *vtable) {
+			VTable *vt = atomicRead(myVTable);
+			// No vtable, no (constructed) instances:
+			if (!vt)
+				return false;
+
+			return vt->sameAs(vtable);
+		}
+
+		// Find equivalent types.
+		virtual void STORM_FN findEquivalentTypes(Named *old, ReplaceContext *ctx);
+
+		// Can we replace something else?
+		virtual MAYBE(Str *) STORM_FN canReplace(Named *old, ReplaceContext *ctx);
+
 	protected:
+		// Replace another type.
+		virtual void STORM_FN doReplace(Named *old, ReplaceTasks *tasks, ReplaceContext *ctx);
+
 		// Use the 'gcType' of the super class. Use only if no additional fields are introduced into
 		// this class.
 		void useSuperGcType();
@@ -299,9 +331,13 @@ namespace storm {
 		// Get the default super type for us.
 		Type *defaultSuper() const;
 
+		// Version of 'setSuper' that allows specifying a 'tasks' instance.
+		void setSuper(MAYBE(Type *) to, MAYBE(ReplaceTasks *) tasks);
+
 		// Internal helper for setSuper. Does the work associated with switching super classes, but
-		// does not change 'super'.
-		void updateSuper();
+		// does not change 'super'. If 'taks' is non-null, then makes sure that the GcType object
+		// will be re-created as needed and recorded inside 'tasks'.
+		void updateSuper(MAYBE(ReplaceTasks *) tasks);
 
 		// Special case for the first Type.
 		static void *operator new(size_t size, Engine &e, GcType *type);
@@ -367,6 +403,9 @@ namespace storm {
 		// acts accordingly.
 		void vtableFnAdded(Function *added);
 
+		// Called when a function has been removed here.
+		void vtableFnRemoved(Function *removed);
+
 		// Search towards the super class for a function overridden by 'fn'. Returns 'true' if an
 		// overridden function was found.
 		Bool vtableInsertSuper(OverridePart *added, Function *original);
@@ -385,6 +424,17 @@ namespace storm {
 		// Invalidate 'isAbstract' for all child classes.
 		void invalidateAbstract();
 
+		// Create a type transform for this class and all subclasses.
+		void createTypeTransformRec(ReplaceTasks *tasks, ReplaceContext *ctx);
+
+		// Create a type transform for this class.
+		void createTypeTransform(ReplaceTasks *tasks, ReplaceContext *ctx);
+
+		// Populate a type transform for this class.
+		void populateTypeTransform(TypeTransform *tfm, ReplaceContext *ctx);
+
+		// Create wrappers for functions from base classes if needed?
+		MAYBE(Named *) createBaseWrapper(Named *fromBase, SimplePart *query, Scope scope);
 	};
 
 	// Allocate an instance of 'type' (slow).
