@@ -9,4 +9,7 @@ namespace gui {
 	App *&appData(Engine &e);
 	RenderMgr *&renderData(Engine &e);
 
+	// Lock for initialization of appData and renderData.
+	os::Lock &dataLock(Engine &e);
+
 }
