@@ -16,22 +16,17 @@ void process_start(struct parameters_to_start *test) {
 	sema_up(&sema);
 }
 
-int start_process(const char *name) {
+void start_process(const char *name) {
 	struct parameters_to_start params;
 	params.start = name;
 	sema_init(&sema, 0);
 
-	int tid = thread_new(process_start, &params);
+	tid_t tid = thread_new(process_start, &params);
 
 	sema_down(&sema);
-
-	return tid;
 }
 
 int main() {
-	int pid = start_process("test");
-	// TODO: Make some kind of printf.
-	print(pid);
-
+	start_process("test");
 	return 0;
 }
